@@ -1,13 +1,12 @@
 #!/bin/bash
 cd debian
-echo '#!/bin/sh'|tee preinst|tee postinst > postrm
+echo '#!/bin/sh'|tee preinst > postrm
 echo 'if [ "$1" = install ]; then' >> preinst
-echo 'if [ "$1" = configure ]; then' >> postinst
 echo 'if [ "$1" = remove ]; then' >> postrm
 for f in `cd maemo4-theme-fixes; find usr|egrep '(png|css)$'`; do
   echo dpkg-divert --package maemo4-theme-fixes --add --rename /$f >> preinst
   echo dpkg-divert --package maemo4-theme-fixes --remove --rename /$f >> postrm
 done
-echo 'fi' |tee -a preinst|tee -a postinst >> postrm
+echo 'fi' |tee -a preinst >> postrm
 echo "Generated control scripts:"
-wc -l preinst postinst postrm
+wc -l preinst postrm
